@@ -29,7 +29,6 @@ import time
 from PySide.QtGui import *
 from PySide.QtCore import *
 from hivemind.attribute import *
-from sets import Set
 
 
 class Element(object):
@@ -81,20 +80,30 @@ class Element(object):
         return elementAttrs
 
 
-class MindMap(Element):
+class MindMap(object):
     '''
     Mind map
 
     @authors: Andrew Golovchenko
     '''
     writable('attributeRegistry')
+    readable('root')
 
-    def __init__(self):
-        '''Initialize mind map'''
-        self.__attributeRegistry = None
-        root = Node()
-        root.setAttributes(text = QApplication.translate('MindMap', 'Root'))
-        self.setRoot(root)
+    def __init__(self, root = None, attributeRegistry = None):
+        '''
+        Initialize mind map
+        @param root: root node of the mind map
+        @type root: Node
+        @param attributeRegistry: the list of all available additional attributes of nodes
+        @type attributeRegistry: AttributeRegistry
+        '''
+        self.__attributeRegistry = attributeRegistry
+        if root is None:
+            root = Node()
+            root.setAttributes(text = QApplication.translate('MindMap', 'Root'))
+        self.__root = root
+        self.__idToNode = {}
+        self._registerSubtree(root)
 
     def processNotification(self, sender, *values, **args):
         '''
@@ -122,31 +131,12 @@ class MindMap(Element):
         for child in root.children:
             self._unregisterSubtree(child)
 
-    def getNodeById(self, id):
+    def getNodeById(self, nodeId):
         '''
         @return: node with the passed id attribute or None if no node found
         @rtype: Node
         '''
-        return self.__idToNode.get(id)
-
-    def getRoot(self):
-        '''
-        @return: root node of the mind map
-        @rtype: Node
-        '''
-        return self.__root
-
-    def setRoot(self, newRoot):
-        '''
-        Set new root for the mind map
-        @param newRoot: new root
-        @type newRoot: Node
-        '''
-        self.__root = newRoot
-        self.__idToNode = {}
-        self._registerSubtree(newRoot)
-
-    root = property(getRoot, setRoot, None, "Root node of the mind map")
+        return self.__idToNode.get(nodeId)
 
 
 class Node(Element, Observable):
@@ -171,6 +161,7 @@ class Node(Element, Observable):
 
     @property
     def effectiveStyle(self):
+        '''Style of the node witch should be used to draw the node'''
         return self.__effectiveStyle if self.__effectiveStyle else settings.get('defaultStyle')
 
     def _propagateEffectiveStyle(self, style):
@@ -197,15 +188,21 @@ class Node(Element, Observable):
 
     @property
     def effectiveLabelColor(self):
-        return self.__effectiveLabelColor if self.__effectiveLabelColor else settings.get('defaultLabelColor')
+        '''Color of the label that should be used to draw the node'''
+        if self.__effectiveLabelColor is not None:
+            return self.__effectiveLabelColor
+        else:
+            return settings.get('defaultLabelColor')
 
     def _propagateEffectiveLabelColor(self, color):
         '''Set label color attribute to Node according inheritance policy'''
         if equal(self.__effectiveLabelColor, color): return
         if self.__labelColor:
             self.__effectiveLabelColor = self.__labelColor
+        elif self.__parent:
+            self.__effectiveLabelColor = self.__parent.__effectiveLabelColor
         else:
-            self.__effectiveLabelColor = self.__parent.__effectiveLabelColor if self.__parent else color
+            self.__effectiveLabelColor = color
         if self.__effectiveLabelColor is not None:
             self.__effectiveLabelColor = QColor(self.__effectiveLabelColor)
         for child in self.__children:
@@ -218,15 +215,21 @@ class Node(Element, Observable):
 
     @property
     def effectiveLabelFont(self):
-        return self.__effectiveLabelFont if self.__effectiveLabelFont else settings.get('defaultLabelFont')
+        '''Font of the label text that should be used to draw the node'''
+        if self.__effectiveLabelFont:
+            return self.__effectiveLabelFont
+        else:
+            return settings.get('defaultLabelFont')
 
     def _propagateEffectiveLabelFont(self, font):
         '''Set label font attribute to Node according inheritance policy'''
         if equal(self.__effectiveLabelFont, font): return
         if self.__labelFont:
             self.__effectiveLabelFont = self.__labelFont
+        elif self.__parent:
+            self.__effectiveLabelFont = self.__parent.__effectiveLabelFont
         else:
-            self.__effectiveLabelFont = self.__parent.__effectiveLabelFont if self.__parent else font
+            self.__effectiveLabelFont = font
         if self.__effectiveLabelFont is not None:
             self.__effectiveLabelFont = QFont(self.__effectiveLabelFont)
         self.__labelFontMetrics = QFontMetricsF(self.effectiveLabelFont)
@@ -240,15 +243,21 @@ class Node(Element, Observable):
 
     @property
     def effectiveEdgeColor(self):
-        return self.__effectiveEdgeColor if self.__effectiveEdgeColor else settings.get('defaultEdgeColor')
+        '''Edge color that should be used to draw the node'''
+        if self.__effectiveEdgeColor:
+            return self.__effectiveEdgeColor
+        else:
+            return settings.get('defaultEdgeColor')
 
     def _propagateEffectiveEdgeColor(self, color):
         '''Set edge color attribute to Node according inheritance policy'''
         if equal(self.__effectiveEdgeColor, color): return
         if self.__edgeColor:
             self.__effectiveEdgeColor = self.__edgeColor
+        elif self.__parent:
+            self.__effectiveEdgeColor = self.__parent.__effectiveEdgeColor
         else:
-            self.__effectiveEdgeColor = self.__parent.__effectiveEdgeColor if self.__parent else color
+            self.__effectiveEdgeColor = color
         if self.__effectiveEdgeColor is not None:
             self.__effectiveEdgeColor = QColor(self.__effectiveEdgeColor)
         for child in self.__children:
@@ -261,7 +270,11 @@ class Node(Element, Observable):
 
     @property
     def effectiveEdgeWidth(self):
-        edgeWidth = self.__effectiveEdgeWidth if self.__effectiveEdgeWidth else settings.get('defaultEdgeWidth')
+        '''Width of the node edge that should be used to draw the node'''
+        if self.__effectiveEdgeWidth:
+            edgeWidth = self.__effectiveEdgeWidth
+        else:
+            edgeWidth = settings.get('defaultEdgeWidth')
         return float(edgeWidth % 10)
 
     def _propagateEffectiveEdgeWidth(self, width):
@@ -269,8 +282,10 @@ class Node(Element, Observable):
         if self.__effectiveEdgeWidth == width: return
         if self.__edgeWidth:
             self.__effectiveEdgeWidth = self.__edgeWidth
+        elif self.__parent:
+            self.__effectiveEdgeWidth = self.__parent.__effectiveEdgeWidth
         else:
-            self.__effectiveEdgeWidth = self.__parent.__effectiveEdgeWidth if self.__parent else width
+            self.__effectiveEdgeWidth = width
         for child in self.__children:
             child._propagateEffectiveEdgeWidth(self.__effectiveEdgeWidth)
 
@@ -281,15 +296,21 @@ class Node(Element, Observable):
 
     @property
     def effectiveEdgeStyle(self):
-        return self.__effectiveEdgeStyle if self.__effectiveEdgeStyle else settings.get('defaultEdgeStyle')
+        '''Edge style that should be used to draw the node'''
+        if self.__effectiveEdgeStyle:
+            return self.__effectiveEdgeStyle
+        else:
+            return settings.get('defaultEdgeStyle')
 
     def _propagateEffectiveEdgeStyle(self, style):
         '''Set edge style attribute to Node according inheritance policy'''
         if self.__effectiveEdgeStyle == style: return
         if self.__edgeStyle:
             self.__effectiveEdgeStyle = self.__edgeStyle
+        elif self.__parent:
+            self.__effectiveEdgeStyle = self.__parent.__effectiveEdgeStyle
         else:
-            self.__effectiveEdgeStyle = self.__parent.__effectiveEdgeStyle if self.__parent else style
+            self.__effectiveEdgeStyle = style
         for child in self.__children:
             child._propagateEffectiveEdgeStyle(self.__effectiveEdgeStyle)
 
@@ -300,6 +321,7 @@ class Node(Element, Observable):
 
     @property
     def effectiveFont(self):
+        '''The font of the node text that should be used to draw the node'''
         return self.__effectiveFont if self.__effectiveFont else settings.get('defaultFont')
 
     def _propagateEffectiveFont(self, font):
@@ -322,15 +344,21 @@ class Node(Element, Observable):
 
     @property
     def effectiveColor(self):
-        return self.__effectiveColor if self.__effectiveColor else settings.get('defaultNodeTextColor')
+        '''The color of the node text that should be used to draw the node'''
+        if self.__effectiveColor:
+            return self.__effectiveColor
+        else:
+            return settings.get('defaultNodeTextColor')
 
     def _propagateEffectiveColor(self, color):
         '''Set color value of Node text content according inheritance policy'''
         if equal(self.__effectiveColor, color): return
         if self.__color:
             self.__effectiveColor = self.__color
+        elif self.__parent:
+            self.__effectiveColor = self.__parent.__effectiveColor
         else:
-            self.__effectiveColor = self.__parent.__effectiveColor if self.__parent else color
+            self.__effectiveColor = color
         if self.__effectiveColor is not None:
             self.__effectiveColor = QColor(self.__effectiveColor)
         self.__colorPalette.setColor(QPalette.Text, self.effectiveColor)
@@ -344,15 +372,21 @@ class Node(Element, Observable):
 
     @property
     def effectiveBgColor(self):
-        return self.__effectiveBgColor if self.__effectiveBgColor else settings.get('defaultNodeBackgroundColor')
+        '''The background color of the node text that should be used to draw the node'''
+        if self.__effectiveBgColor:
+            return self.__effectiveBgColor
+        else:
+            return settings.get('defaultNodeBackgroundColor')
 
     def _propagateEffectiveBgColor(self, color):
         '''Set background color value of Node according inheritance policy'''
         if equal(self.__effectiveBgColor, color): return
         if self.__background_color:
             self.__effectiveBgColor = self.__background_color
+        elif self.__parent:
+            self.__effectiveBgColor = self.__parent.__effectiveBgColor
         else:
-            self.__effectiveBgColor = self.__parent.__effectiveBgColor if self.__parent else color
+            self.__effectiveBgColor = color
         if self.__effectiveBgColor is not None:
             self.__effectiveBgColor = QColor(self.__effectiveBgColor)
         for child in self.__children:
@@ -400,10 +434,9 @@ class Node(Element, Observable):
         self.__icons = []
         self.__nodeAttribute = None
         self.__children = []
-        if self.__id is None:
+        if self.__id is None: #pylint: disable=E0203
             self.__created = int(time.time() * 1000.0)
             self.__modified = self.__created
-#           FIXME: use integer value instead of string in new file format
             self.__id = 'ID_0%d' % id(self)
         # local fields
         self.__isHtmlContent = False
@@ -420,23 +453,11 @@ class Node(Element, Observable):
         '''Return private field value'''
         return self.__dict__['_Node__' + fieldName]
 
-#    TODO: implement class
-#    class _Notifier(object):
-#        def __init__(self):
-#            self.__maxNotifyLevel = -1 # -1 <=> no notification will be send
-#        def reset(self):
-#            self.__maxNotifyLevel = -1
-#        def updateNotifyLevel(self, level):
-#            self.__maxNotifyLevel = max(self.__maxNotifyLevel, level)
-#        def notify(self):
-#            # emit only one signal with max level of change
-#            self.notifyObservers(self, type = _Notifier.__SIGNALS[self.__maxNotifyLevel])
-
-    __LOCAL_ATTRIBUTES = Set(('cloud', 'folded', 'icons', 'labelText', 'link'))
+    __LOCAL_ATTRIBUTES = set(('cloud', 'folded', 'icons', 'labelText', 'link'))
     '''Properties which emit "localeAttributeChanged" notification and not has a setter'''
 
-    __NONEVENT_ATTRIBUTES = Set(('created', 'id', 'modified', 'encrypted_content', 'nodeAttribute', 'note',
-                                 'hgap', 'vgap', 'vshift'))
+    __NONEVENT_ATTRIBUTES = set(('created', 'id', 'modified', 'encrypted_content',
+            'nodeAttribute', 'note', 'hgap', 'vgap', 'vshift'))
     '''Properties which not emit any notifications and not has a setter'''
 
     __LOCAL_CHANGE_LEVEL, __INHERITED_CHANGE_LEVEL = range(2)
@@ -453,7 +474,6 @@ class Node(Element, Observable):
         @type attributes: dict
         '''
         maxNotifyLevel = -1 # -1 <=> no notification will be send
-        # TODO optimize: use more efficient switch
         for attrName, attrValue in attributes.items():
             if attrName == 'font':
                 self._setFont(attrValue)
@@ -470,7 +490,6 @@ class Node(Element, Observable):
             elif attrName == 'html':
                 self._setHtml(attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__LOCAL_CHANGE_LEVEL)
-#           FIXME: differ levels by type
             elif attrName == 'edgeWidth':
                 self._setEdgeWidth(attrValue)
                 maxNotifyLevel = max(maxNotifyLevel, Node.__INHERITED_CHANGE_LEVEL)
@@ -505,8 +524,8 @@ class Node(Element, Observable):
     WRITABLE_PROPERTIES = ('created', 'id', 'modified', 'encrypted_content', 'nodeAttribute',
                              'note', 'icons', 'font', 'color', 'left', 'edgeColor',
                              'edgeWidth', 'edgeStyle', 'link', 'hgap', 'vgap', 'vshift',
-                             'cloud', 'folded', 'background_color', 'style', 'text', 'labelText',
-                             'labelFont', 'labelColor')
+                             'cloud', 'folded', 'background_color', 'style', 'text',
+                             'labelText', 'labelFont', 'labelColor')
     '''Node writable properties that can be set with setAttributes() method'''
 
     def getAttributes(self, *propNames, **options):
@@ -656,16 +675,18 @@ class Node(Element, Observable):
         @rtype: int
         '''
         node = self
-        _depth = 0
+        nodeDepth = 0
         while node.parent is not None:
-            _depth += 1
+            nodeDepth += 1
             node = node.parent
-        return _depth
+        return nodeDepth
 
     def createChildPrototype(self, **attributes):
         '''
         Create a new node without adding it into the children list.
-        Attributes of the created node are set according to the inheritance policy
+        Attributes of the created node are set according to the inheritance policy.
+        Prototype is not a child of this node yet. You must add it afterwards with the
+        addChilde method
         
         @param attributes: initialization attributes
         @type attributes: dict
@@ -674,7 +695,6 @@ class Node(Element, Observable):
         @rtype: Node
         '''
         child = Node(**attributes)
-        # FIXME prototype is not a child yet!
         child.__parent = self
         # set inheritable attributes
         child.__left = self.__left
@@ -740,8 +760,6 @@ class Node(Element, Observable):
         @rtype: QSizeF
         '''
         if self.__labelText is None: return QSizeF(0.0, 0.0)
-#       FIXME: 1) QFontMetrics.xxx methods are very slow! Use cached size value
-#              2) QFontMetrics.width() works incorrectly with italic fonts => use QFontMetrics.size() instead
         return QSizeF(self.__labelFontMetrics.width(self.__labelText),
                       self.__labelFontMetrics.overlinePos() -
                       self.__labelFontMetrics.underlinePos())
