@@ -48,6 +48,7 @@ class DesktopEditNodeDialog(EditNodeDialog):
 
     def _initComponents(self):
         '''Form initialization'''
+        #pylint: disable = W0201
         toolbar = QToolBar(self)
         self._boldAction.setToolTip(self.tr('Bold'))
         self._boldAction.setIcon(QIcon.fromTheme('format-text-bold'))
@@ -208,6 +209,7 @@ class DesktopAboutDialog(AboutDialog):
 
     def _createComponents(self):
         '''Create components'''
+        #pylint: disable = W0201
         AboutDialog._createComponents(self)
         self._logo.setPixmap(self._logoImage.scaled(QSize(72, 72)))
         palette = self.palette()
@@ -270,7 +272,7 @@ class DesktopAboutDialog(AboutDialog):
         '''Form initialization'''
         self.setMinimumWidth(500)
         self.setMinimumHeight(300)
-        self.__close = QDialogButtonBox(QDialogButtonBox.Close)
+        close = QDialogButtonBox(QDialogButtonBox.Close)
         headerInfoLayout = QVBoxLayout()
         headerInfoLayout.addWidget(self._name)
         headerInfoLayout.addWidget(self._version)
@@ -283,9 +285,9 @@ class DesktopAboutDialog(AboutDialog):
         mainLayout = QVBoxLayout()
         mainLayout.addLayout(headerLayout)
         mainLayout.addWidget(self._tabWidget)
-        mainLayout.addWidget(self.__close)
+        mainLayout.addWidget(close)
         self.setLayout(mainLayout)
-        self.__close.connect(SIGNAL('rejected()'), self.close)
+        close.connect(SIGNAL('rejected()'), self.close)
 
 
 class DesktopEditEdgeDialog(EditEdgeDialog):
@@ -372,13 +374,13 @@ class DesktopSettingsDialog(SettingsDialog):
         SettingsDialog._accept(self)
 
 
-class DesktopXMPPCredentialsDialog(XMPPCredentialsDialog):
+class DesktopNetworkConnectionDialog(NetworkConnectionDialog):
     '''
-    XMPP credentials dialog for Desktop platform
+    Network connection dialog for Desktop platform
     @author: Oleg Kandaurov
     '''
-    def __init__(self, client = False, parent = None):
-        XMPPCredentialsDialog.__init__(self, client, parent)
+    def __init__(self, credentials, client, parent = None):
+        NetworkConnectionDialog.__init__(self, credentials, client, parent)
 
 
 class DesktopAffiliationDialog(AffiliationDialog):
