@@ -121,7 +121,9 @@ class DesktopMainWindow(AbstractMainWindow):
                 self._actionBag.addNodeAction, self._actionBag.addSiblingNodeBelowAction,
                 self._actionBag.addSiblingNodeAboveAction, self._actionBag.editNodeAction,
                 self._actionBag.editNodeIconsAction, self._actionBag.editLabelAction,
-                self._actionBag.editEdgeAction, self._actionBag.editAffiliationAction]
+                self._actionBag.editEdgeAction, self._actionBag.editAffiliationAction,
+                self._actionBag.startPubSubClientAction, self._actionBag.connectXMPPAction,
+                self._actionBag.startPubSubServiceAction]
         for action in actionsWithEllipses:
             action.setText(action.text() + '...')
 
@@ -141,6 +143,12 @@ class DesktopMainWindow(AbstractMainWindow):
         menu.addSeparator()
         menu.addAction(self._actionBag.settingsAction)
         menu = self.menuBar().addMenu(self.tr('&Collaboration'))
+        advMenu = QMenu(self.tr('&Advanced'))
+        advMenu.addAction(self._actionBag.connectXMPPAction)
+        advMenu.addAction(self._actionBag.startPubSubServiceAction)
+        advMenu.addAction(self._actionBag.startPubSubClientAction)
+        advMenu.addAction(self._actionBag.stopProtocolAction)
+        menu.addMenu(advMenu)
         menu.addAction(self._actionBag.startNetworkServerAction)
         menu.addAction(self._actionBag.startNetworkClientAction)
         menu.addAction(self._actionBag.editAffiliationAction)
