@@ -26,7 +26,7 @@ Abstract dialog classes
 '''
 
 import hivemind.settings as settings
-import resource
+import hivemind.resource as resource
 from PySide.QtGui import *
 from PySide.QtCore import *
 from hivemind.attribute import *
@@ -43,6 +43,7 @@ class CommonDialog(SearchingTrMixin, QDialog):
         Create OK and Cancel buttons and connect them to appropriate handlers
         '''
         QDialog.__init__(self, parent)
+        SearchingTrMixin.__init__(self)
         self._buttonBox = QDialogButtonBox()
         self._okButton = self._buttonBox.addButton(QDialogButtonBox.Ok)
         self._cancelButton = self._buttonBox.addButton(QDialogButtonBox.Cancel)
@@ -69,6 +70,9 @@ class EditNodeDialog(CommonDialog):
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Node editor'))
         self.__node = node
+        self.__background = None
+        self.__font = None
+        self.__color = None
         self._isHtml = self.__node.isHtml()
         self.__newAttributes = None
         self._isHtmlSourceMode = False
@@ -77,6 +81,7 @@ class EditNodeDialog(CommonDialog):
 
     def _createComponents(self):
         '''Create components and actions'''
+        #pylint: disable = W0201
         # init edit widget
         self._editor = SpecialTextEdit()
         self.connect(self._editor, SIGNAL('accept'), self._accept)
@@ -120,12 +125,12 @@ class EditNodeDialog(CommonDialog):
         self._editor.connect(SIGNAL('currentCharFormatChanged(QTextCharFormat)'),
                              self._currentCharFormatChanged)
 
-    def _currentCharFormatChanged(self, format):
+    def _currentCharFormatChanged(self, textFormat):
         '''
         Update tool bar if the current character format has changed
-        @type format: QTextCharFormat
+        @type textFormat: QTextCharFormat
         '''
-        self._fontChanged(format.font())
+        self._fontChanged(textFormat.font())
 
     def _fontChanged(self, font):
         '''
@@ -308,7 +313,7 @@ class EditNodeDialog(CommonDialog):
         self._setColor(None)
         self._setBackgroundColor(None)
 
-    def _mergeFormat(self, format):
+    def _mergeFormat(self, textFormat):
         '''
         Merge current format in text editor and new format
         @type format: QTextCharFormat
@@ -318,8 +323,8 @@ class EditNodeDialog(CommonDialog):
             cursor.select(QTextCursor.Document)
         elif not cursor.hasSelection():
             cursor.select(QTextCursor.WordUnderCursor)
-        cursor.mergeCharFormat(format)
-        self._editor.mergeCurrentCharFormat(format)
+        cursor.mergeCharFormat(textFormat)
+        self._editor.mergeCurrentCharFormat(textFormat)
 
 
 class FontDialog(CommonDialog):
@@ -337,14 +342,18 @@ class FontDialog(CommonDialog):
         '''
         CommonDialog.__init__(self, parent)
         self.setWindowFlags(Qt.Window)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        self.setAttribute(Qt.WA_Maemo5StackedWindow) #pylint: disable=E1101
+        self.__font = font
         self._initComponents(font)
 
     def _initComponents(self, font):
+        '''Init components'''
+        #pylint: disable = W0201
         self.__comboFont = QFontComboBox()
         self.__comboFont.setCurrentFont(font)
         self.__comboSize = QComboBox()
-        self.__comboSize.addItems([str(value) for value in QFontDatabase().pointSizes(self.__comboFont.currentFont().family())])
+        self.__comboSize.addItems([str(value) for value in \
+                QFontDatabase().pointSizes(self.__comboFont.currentFont().family())])
         self.__comboSize.setEditable(True)
         index = self.__comboSize.findText(str(font.pointSize()), Qt.MatchExactly)
         if index == -1:
@@ -352,7 +361,8 @@ class FontDialog(CommonDialog):
         else: self.__comboSize.setCurrentIndex(index)
         self.__sampleText = QLineEdit(self.tr('ABCDE abcde'))
         self.__sampleText.setFrame(False)
-        self.__sampleText.setFont(QFont(self.__comboFont.currentFont().family(), int(self.__comboSize.currentText())))
+        self.__sampleText.setFont(QFont(self.__comboFont.currentFont().family(),
+                int(self.__comboSize.currentText())))
         self.__sampleText.setAlignment(Qt.AlignHCenter | Qt.AlignVCenter)
         layout = QGridLayout()
         layout.addWidget(self.__comboFont, 0, 0, 1, 3)
@@ -391,6 +401,7 @@ class FontDialog(CommonDialog):
         '''
         self._setLabelFormat()
 
+
 class EditLabelDialog(CommonDialog):
     '''
     Dialog for edge label editing
@@ -406,11 +417,15 @@ class EditLabelDialog(CommonDialog):
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Edit Label'))
         self.__node = node
+        self.__color = None
+        self.__font = None
+        self.__newAttributes = {}
         self._createComponents()
         self._initEditor()
 
     def _createComponents(self):
         '''Create components and actions'''
+        #pylint: disable = W0201
         self._editor = SpecialTextEdit()
         self._boldAction = QAction(self)
         self._boldAction.setCheckable(True)
@@ -607,16 +622,16 @@ class EditLabelDialog(CommonDialog):
         fmt.setFont(newFont)
         self._mergeFormat(fmt)
 
-    def _mergeFormat(self, format):
+    def _mergeFormat(self, textFormat):
         '''
         Merge current format in text editor and new format
 
-        @type format: QTextCharFormat
+        @type textFormat: QTextCharFormat
         '''
         cursor = self._editor.textCursor()
         cursor.select(QTextCursor.Document)
-        cursor.mergeCharFormat(format)
-        self._editor.mergeCurrentCharFormat(format)
+        cursor.mergeCharFormat(textFormat)
+        self._editor.mergeCurrentCharFormat(textFormat)
 
     def _accept(self):
         '''
@@ -666,10 +681,12 @@ class IconDialog(CommonDialog):
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Icon selector'))
         self.__node = node
+        self.__newAttributes = {}
         self._createComponents()
 
     def _createComponents(self):
         '''Create components'''
+        #pylint: disable = W0201
         if len(self.__node.icons) > IconList.MAX_ICON_COUNT:
             self._listScene = IconList(self.__node.icons[:10], self)
         else: self._listScene = IconList(self.__node.icons, self)
@@ -717,6 +734,8 @@ class AboutDialog(CommonDialog):
         self._createComponents()
 
     def _createComponents(self):
+        '''Create components'''
+        #pylint: disable = W0201
         self._logo = QLabel()
         self._logoImage = resource.getImage('logo')
         self._info = QLabel(self.tr("Collaborative mind map editor"))
@@ -736,11 +755,16 @@ class EditEdgeDialog(CommonDialog):
         CommonDialog.__init__(self, parent)
         self.setWindowTitle(self.tr('Edge editor'))
         self.__node = node
+        self.__newAttributes = {}
+        self.__color = None
+        self.__widthToButton = None
+        self.__styleToButton = None
         self._createComponents()
         self._initEditor()
 
     def _createComponents(self):
         '''Create components'''
+        #pylint: disable = W0201
         # Setting up width view
         self._widthLabel = QLabel(self.tr('Width'))
         self._widthParent = QRadioButton(self.tr('Parent'))
@@ -856,28 +880,33 @@ class SettingsDialog(CommonDialog):
         settings.set(**newSettings)
         if oldLocale != settings.get('locale'):
             QMessageBox.information(self, self.tr('Settings changed'),
-                    self.tr('The language settings will be applied on restart of the application!'))
+                    self.tr('The language settings will be applied on restart \
+                    of the application!'))
         QDialog.accept(self)
 
-class XMPPCredentialsDialog(CommonDialog):
+class NetworkConnectionDialog(CommonDialog):
     '''
-    Abstract class for xmpp credentials dialog
+    Abstract class for network connection dialog
     @author: Oleg Kandaurov
     '''
-    def __init__(self, client = False, parent = None):
+    def __init__(self, credentials, client, parent = None):
         '''
+        @param credentials: Show XMPP credentials
+        @type credentials: bool
+        @param client: Show client or server dialogs
+        @type client: bool
         @type parent: QWidget
         '''
         CommonDialog.__init__(self, parent)
+        self.__credentials = credentials
         self.__client = client
-        self.setWindowTitle(self.tr('XMPP Credentials'))
+        self.setWindowTitle(self.tr('Network Connection'))
         self._createComponents()
         self._initComponents()
 
     def _createComponents(self):
-        '''
-        Create Components
-        '''
+        '''Create Components'''
+        #pylint: disable = W0201
         self.__newAttributes = dict()
         mailRegexp = QRegExp('[A-Za-z0-9._%+-]+@(?:[A-Za-z0-9-]+\\.)+[A-Za-z]{2,6}')
         self._userBinder = LineEditBinder('userJid', settings.get('userJid'), mailRegexp)
@@ -885,40 +914,43 @@ class XMPPCredentialsDialog(CommonDialog):
         self._passwordBinder = LineEditBinder('password', '')
         self._passwordBinder.setEchoMode(QLineEdit.Password)
         self._passwordLabel = QLabel(self.tr('Password:'))
-        self._serviceBinder = LineEditBinder('serviceJid', settings.get('serviceJid'), mailRegexp)
+        self._serviceBinder = LineEditBinder('serviceJid', settings.get('serviceJid'),
+                mailRegexp)
         self._serviceLabel = QLabel(self.tr('Service JID:'))
         self._readOnlyBinder = CheckBoxBinder('readOnly', settings.get('readOnly'))
         self._readOnlyBinder.setText(self.tr('Read only'))
 
     def _initComponents(self):
+        '''Init components'''
         mainLayout = QVBoxLayout()
         formLayout = QFormLayout()
-        formLayout.addRow(self._userLabel, self._userBinder)
-        formLayout.addRow(self._passwordLabel, self._passwordBinder)
-        if self.__client:
+        if self.__credentials:
+            formLayout.addRow(self._userLabel, self._userBinder)
+            formLayout.addRow(self._passwordLabel, self._passwordBinder)
+        if self.__client == True:
             formLayout.addRow(self._serviceLabel, self._serviceBinder)
-        else:
+        elif self.__client == False:
             formLayout.addRow(self._readOnlyBinder)
         mainLayout.addLayout(formLayout)
         mainLayout.addWidget(self._buttonBox)
         self.setLayout(mainLayout)
 
     def _accept(self):
-        '''
-        Hide the dialog, update attributes
-        set result code to Accepted and save new jids
-        '''
-        if not self._serviceBinder.isValid() and self.__client or not self._userBinder.isValid():
+        '''Hide the dialog, update attributes'''
+        if not self._serviceBinder.isValid() and self.__client or \
+        not self._userBinder.isValid():
             QMessageBox.critical(self, self.tr('Incorrect JID!'),
                     self.tr('Please, enter correct jabber id.'))
             return
-        self.__newAttributes['userJid'] = self._userBinder.retrieve().values().pop()
+        if self.__credentials:
+            self.__newAttributes['userJid'] = self._userBinder.retrieve().values().pop()
         if self.__client:
             self.__newAttributes['serviceJid'] = self._serviceBinder.retrieve().values().pop()
         else:
             self.__newAttributes['readOnly'] = self._readOnlyBinder.retrieve().values().pop()
         settings.set(**self.__newAttributes)
-        self.__newAttributes['password'] = self._passwordBinder.retrieve().values().pop()
+        if self.__credentials:
+            self.__newAttributes['password'] = self._passwordBinder.retrieve().values().pop()
         QDialog.accept(self)
 
     def attributes(self):
@@ -952,6 +984,7 @@ class SideSelectionDialog(CommonDialog):
         '''
         Create components
         '''
+        #pylint: disable = W0201
         self.__label = QLabel(self.tr('Select node position'))
         self.__left = QPushButton(self.tr('Left'))
         self.__right = QPushButton(self.tr('Right'))
@@ -997,12 +1030,16 @@ class AffiliationDialog(CommonDialog):
         '''
         Create components
         '''
+        #pylint: disable = W0201
         self.__model = QStandardItemModel(0, 3)
         self.__delegate = AffiliationDelegate()
         self.__view = QTableView()
         self.__model.setHorizontalHeaderLabels([self.tr('JID'),
                 self.tr('Affiliation'), self.tr('Status')])
         self.__view.setModel(self.__model)
+        horizontalHeader = self.__view.horizontalHeader()
+        horizontalHeader.setResizeMode(QHeaderView.Stretch)
+        horizontalHeader.setStretchLastSection(True)
         self.__view.setItemDelegateForColumn(1, self.__delegate)
         self.__jidLabel = QLabel(self.tr('JID'))
         self.__jidEdit = QLineEdit()
@@ -1052,17 +1089,13 @@ class AffiliationDialog(CommonDialog):
                 self.__affiliationCombo.itemData(self.__affiliationCombo.currentIndex()))
         self.__jidEdit.clear()
 
-    def updateStatus(self, event, subscriber, node, optional):
+    def updateStatus(self, event, subscriber):
         '''
         Update status of widgets according to received event
         @param event: Type of event
         @type event: str
         @param subscriber: Subcriber that generates event
         @type subscriber: str
-        @param node: Node from which event received
-        @type node: str
-        @param optional: Subscribers count
-        @type optional: int
         '''
         for row in range(0, self.__model.rowCount()):
             if self.__model.index(row, 0).data() == subscriber:
@@ -1089,6 +1122,8 @@ class AffiliationDialog(CommonDialog):
                 newAffiliation)
         self.__model.setData(self.__model.index(self.__model.rowCount() - 1, 0),
                 jid)
+        self.__model.item(self.__model.rowCount() - 1, 0).setEditable(False)
+        self.__model.item(self.__model.rowCount() - 1, 2).setEditable(False)
 
     def getAffiliations(self):
         '''
