@@ -25,7 +25,7 @@ View delegates for core objects
 '''
 
 import hivemind.settings as settings
-import resource
+import hivemind.resource as resource
 import math
 from hivemind.attribute import *
 from hivemind.core import MindMap
@@ -71,7 +71,10 @@ class MindMapDelegate(QGraphicsScene):
         QGraphicsScene.__init__(self)
         settings.connect(self._settingsChanged)
         self.__nodeToDelegate = {}
+        self.__rootDelegate = None
+        self.__currentLayerDepth = None
         self.__currentNode = None
+        self.__mindMap = None
         # used as 'switch' operator in processNotification() method
         self.__signalHandlers = {'childNodeAdded' : self.addNodeDelegate,
                                  'childNodeRemoved' : self.removeNodeDelegate,
@@ -79,7 +82,11 @@ class MindMapDelegate(QGraphicsScene):
                                  'localAttributeChanged' : self.nodeBoundsChanged,
                                  'inheritedAttributeChanged' : self.inheritedAttributeChanged}
         self.setMap(MindMap())
-        self._createNavigateActions()
+        self.__selectLeftNodeAction = self.createAction(None, self._selectLeftNode, 'Left')
+        self.__selectRightNodeAction = self.createAction(None, self._selectRightNode, 'Right')
+        self.__selectUpNodeAction = self.createAction(None, self._selectUpNode, 'Up')
+        self.__selectDownNodeAction = self.createAction(None, self._selectDownNode, 'Down')
+        self.__selectRootNodeAction = self.createAction(None, self._selectRootNode, 'Escape')
 
     def createAction(self, text, handler, shortcut = None, icon = None):
         '''
@@ -96,19 +103,13 @@ class MindMapDelegate(QGraphicsScene):
         if handler: action.connect(SIGNAL('triggered()'), handler)
         return action
 
-    def _createNavigateActions(self):
-        self.__selectLeftNodeAction = self.createAction(None, self._selectLeftNode, 'Left')
-        self.__selectRightNodeAction = self.createAction(None, self._selectRightNode, 'Right')
-        self.__selectUpNodeAction = self.createAction(None, self._selectUpNode, 'Up')
-        self.__selectDownNodeAction = self.createAction(None, self._selectDownNode, 'Down')
-        self.__selectRootNodeAction = self.createAction(None, self._selectRootNode, 'Escape')
-
     def addNodeDelegate(self, node):
         '''
         This method called, then signal for created delegate has come
         @param node: node was clicked
         @type node: Node
         '''
+        #pylint: disable=C0103
         self._addDelegatesForNodeSubtree(node)
         self.positionNodes()
         self.currentNode = node
@@ -225,8 +226,8 @@ class MindMapDelegate(QGraphicsScene):
     def _updateSceneRectangle(self):
         '''Set new scene rectangle for the map. Add additional margin.'''
         sceneRect = self.itemsBoundingRect()
-        sceneRect.adjust(-self._MAP_MARGIN_WIDTH, -self._MAP_MARGIN_HEIGHT, self._MAP_MARGIN_WIDTH,
-                         self._MAP_MARGIN_HEIGHT)
+        sceneRect.adjust(-self._MAP_MARGIN_WIDTH, -self._MAP_MARGIN_HEIGHT,
+                self._MAP_MARGIN_WIDTH, self._MAP_MARGIN_HEIGHT)
         self.setSceneRect(sceneRect)
 
     def createNodeDelegates(self, parentNodeDelegate):
@@ -289,10 +290,11 @@ class MindMapDelegate(QGraphicsScene):
         parent = self._getParent(position)
         if parent is None: return None, None
         above, below = self._neighbourDelegates(position, parent)
-        right = self._isPositionToTheRight(position, self.__rootDelegate)
+        right = MindMapDelegate.isPositionToTheRight(position, self.__rootDelegate)
         if self.__rootDelegate.textRectOnScene().contains(position):
-            return parent, NodeLocation(right, self._isPositionAbove(position, self.__rootDelegate), None)
-        nearest = self._nearestDelegateByOrdinate(position, above, below)
+            return parent, NodeLocation(right,
+                    MindMapDelegate.isPositionAbove(position, self.__rootDelegate), None)
+        nearest = MindMapDelegate.nearestDelegateByOrdinate(position, above, below)
         leftSideOfTheNode = (position.x() < nearest.textRectOnScene().center().x())
         if leftSideOfTheNode and right or not leftSideOfTheNode and not right:
             if below is None:
@@ -301,7 +303,8 @@ class MindMapDelegate(QGraphicsScene):
                 insertPos = parent.node.getChildPosition(below.node)
             return parent, NodeLocation(right, None, insertPos)
         else:
-            return nearest, NodeLocation(right, self._isPositionAbove(position, nearest), None)
+            return nearest, NodeLocation(
+                    right, MindMapDelegate.isPositionAbove(position, nearest), None)
 
     def _neighbourDelegates(self, position, parent):
         '''
@@ -314,8 +317,8 @@ class MindMapDelegate(QGraphicsScene):
         if parent is None: return None, None
         prev = None
         for node in parent.node.children:
-            if node.left is self._isPositionToTheRight(position, self.__rootDelegate):
-                continue
+            if node.left == MindMapDelegate.isPositionToTheRight(
+                    position, self.__rootDelegate): continue
             child = self.getDelegate(node)
             if prev is None:
                 if position.y() < child.textRectOnScene().center().y():
@@ -326,7 +329,8 @@ class MindMapDelegate(QGraphicsScene):
             prev = child
         return prev, None
 
-    def _nearestDelegateByOrdinate(self, position, above, below):
+    @classmethod
+    def nearestDelegateByOrdinate(cls, position, above, below):
         '''
         Return one of the delegates that are closer to the position by y-coordinate
 
@@ -341,7 +345,8 @@ class MindMapDelegate(QGraphicsScene):
             return above
         return above if above.yDistanceTo(position) < below.yDistanceTo(position) else below
 
-    def _nearestDelegateByAbscissa(self, position, delegates):
+    @classmethod
+    def nearestDelegateByAbscissa(cls, position, delegates):
         '''
         Return one of the delegates that are closer to the position by x-coordinate
 
@@ -373,10 +378,11 @@ class MindMapDelegate(QGraphicsScene):
                 parents.add(child.parentItem())
             else:
                 parents.add(self.__rootDelegate)
-        parent = self._nearestDelegateByAbscissa(position, list(parents))
+        parent = MindMapDelegate.nearestDelegateByAbscissa(position, list(parents))
         return parent
 
-    def _isPositionToTheRight(self, position, item):
+    @classmethod
+    def isPositionToTheRight(cls, position, item):
         '''
         Determine if the given position is to the right from the item
 
@@ -386,7 +392,8 @@ class MindMapDelegate(QGraphicsScene):
         '''
         return position.x() > item.textRectOnScene().center().x()
 
-    def _isPositionAbove(self, position, item):
+    @classmethod
+    def isPositionAbove(cls, position, item):
         '''
         Determine if the given position is above the item
 
@@ -477,6 +484,9 @@ class MindMapDelegate(QGraphicsScene):
                 return
 
     def onItemClicked(self, rightButton, item, parent, childLocation):
+        '''
+        Update scene attributes according to clicked item
+        '''
         if item is not None:
             self.currentNode = item.node
             self.__currentLayerDepth = item.node.depth()
@@ -517,6 +527,10 @@ class NodeDelegate(QGraphicsItem):
         self.__verticalSpace = 0
         self.__selected = False
         self.__positionChanged = True
+        self.__linkPoint = None
+        self.__parentLinkPoint = None
+        self.__textBoundingRect = None
+        self.__boundingRect = None
         QGraphicsItem.__init__(self, parent)
         self.updateNodeBounds(False)
         self._updateNodePosition()
@@ -580,7 +594,8 @@ class NodeDelegate(QGraphicsItem):
         if self.__node.folded and self.__node.effectiveStyle == 'fork':
             self.__verticalSpace += NodeDelegate.__FOLD_MARK_SIZE
 
-    def _computeVerticalSpace(self, subtree):
+    @classmethod
+    def computeVerticalSpace(cls, subtree):
         '''
         Calculate vertical space needed for current node specified subtree
 
@@ -619,8 +634,9 @@ class NodeDelegate(QGraphicsItem):
         @param nodes: child nodes to position
         @type nodes: list of NodeDelgates
         '''
+        #pylint: disable=W0212
         baseVerticalPosition = (self.textBoundingRect().height() - \
-            self._computeVerticalSpace(nodes)) / 2.0
+            NodeDelegate.computeVerticalSpace(nodes)) / 2.0
         initialVerticalPosition = baseVerticalPosition
         for child in nodes:
             verticalPosition = baseVerticalPosition + (child.verticalSpace - \
@@ -656,8 +672,7 @@ class NodeDelegate(QGraphicsItem):
         '''
         self._calculateTextBoundingRect()
         self._calculateLinkPoint()
-        if self.parentItem() is None:
-            self._updateNodePosition()
+        self._updateNodePosition()
         if propagate:
             for delegate in self.childItems():
                 delegate.updateNodeBounds(self)
@@ -702,8 +717,7 @@ class NodeDelegate(QGraphicsItem):
         bgColor = self.__node.effectiveBgColor
         if self.__selected:
             bgColor = settings.get('defaultSelectedNodeBackgroundColor')
-        # TODO user color value from settings instead of Qt.darkGray
-        painter.setPen(QPen(Qt.darkGray, 1.0))
+        painter.setPen(QPen(edgeColor, 1.0))
         painter.setBrush(bgColor)
         # if root node
         if self.__node.parent is None:
@@ -740,15 +754,18 @@ class NodeDelegate(QGraphicsItem):
         if self.__node.left:
             labelPoint.setX(labelPoint.x() + NodeDelegate.__LABEL_MARGIN)
         else:
-            labelPoint.setX(labelPoint.x() - self.__node.labelSize.width() - NodeDelegate.__LABEL_MARGIN)
+            labelPoint.setX(labelPoint.x() - self.__node.labelSize.width() - \
+                    NodeDelegate.__LABEL_MARGIN)
         labelPoint.setY(labelPoint.y() - self.__node.effectiveEdgeWidth / 2.0 - 2.0)
         painter.drawText(labelPoint, self.__node.labelText)
-        pen = QPen(self.__node.effectiveEdgeColor, self.__node.effectiveEdgeWidth, Qt.SolidLine, Qt.RoundCap)
+        pen = QPen(self.__node.effectiveEdgeColor, self.__node.effectiveEdgeWidth,
+                Qt.SolidLine, Qt.RoundCap)
         if self.__node.effectiveEdgeStyle.startswith('sharp') and not self.__node.children:
             pen.setWidthF(0.5)
         painter.setPen(pen)
         linkPoint = self.linkPoint
-        painter.drawLine(linkPoint, QPointF(linkPoint.x() + self.linkPointOffset(), linkPoint.y()))
+        painter.drawLine(linkPoint, QPointF(linkPoint.x() + self.linkPointOffset(),
+                linkPoint.y()))
 
     def _paintRoot(self, painter, boundRect):
         '''
@@ -765,7 +782,10 @@ class NodeDelegate(QGraphicsItem):
         self._paintNodeContent(painter)
 
     def _paintFoldedMark(self, painter, boundRect):
-        painter.setPen(QPen(Qt.darkGray, 1.0))
+        '''
+        Paint folded mark
+        '''
+        painter.setPen(QPen(self.__node.effectiveEdgeColor, 1.0))
         painter.setBrush(Qt.white)
         markPoint = self.linkPoint
         if markPoint is None: # root
@@ -789,6 +809,7 @@ class NodeDelegate(QGraphicsItem):
         @return: Root's bounding rect
         @rtype: QRectF
         '''
+        #pylint: disable=C0103
         # 'a' and 'b' - sides of ellipse; 'e' - eccentricity
         b = size.height()
         a = size.width()
@@ -862,7 +883,7 @@ class NodeDelegate(QGraphicsItem):
         if self.parentItem() is None:
             self.__boundingRect = self.textBoundingRect()
             return
-        linkPoint = self._parentLinkPoint()
+        linkPoint = QPointF(self.__parentLinkPoint)
         textBounds = self.textBoundingRect()
         left = min(linkPoint.x(), textBounds.x())
         top = min(linkPoint.y(), textBounds.y(), -self._labelOverhead())
@@ -925,7 +946,6 @@ class NodeDelegate(QGraphicsItem):
         @return: difference between top points value of node (text bounding rect) and its label
         @rtype: float
         '''
-#       TODO: consider angle of label on inclined edges
         if not self.__node.labelText: return 0.0
         textBounds = self.textBoundingRect()
         # 2.0 is a decorative space between label and edge
@@ -949,68 +969,86 @@ class NodeDelegate(QGraphicsItem):
             parentLinkPoint.setY(parentRect.height())
         self.__parentLinkPoint = self.mapFromParent(parentLinkPoint)
 
-    def _parentLinkPoint(self):
-        '''
-        Get connection point to parent node
-
-        @return: connection point in current node coordinates
-        @rtype: QPointF
-        '''
-        return QPointF(self.__parentLinkPoint)
-
     def _paintEdge(self, painter, style):
         '''
         Paint join link from parent node to current
-
         @type painter: QPanter
-
         @param style: style of node join link
         @type style: string
         '''
+        paintEdge = {'bezier': self._paintBezierEdge,
+                'sharp_bezier': self._paintSharpBezierEdge,
+                'linear': self._paintLinearEdge,
+                'sharp_linear': self._paintSharpLinearEdge}
         painter.setPen(QPen(self.__node.effectiveEdgeColor, self.__node.effectiveEdgeWidth,
                 Qt.SolidLine, Qt.FlatCap, Qt.RoundJoin))
-        startPoint = self._parentLinkPoint()
+        startPoint = QPointF(self.__parentLinkPoint)
         endPoint = self.linkPoint
         endPoint.setX(endPoint.x() + self.linkPointOffset())
+        paintEdge[style](painter, startPoint, endPoint)
+
+    def _paintBezierEdge(self, painter, startPoint, endPoint):
+        '''
+        Paint edge with bezier style
+        '''
+        #pylint: disable=R0201
         curvePath = QPainterPath()
-        if style == 'bezier':
-            curveRect = QRectF(startPoint, endPoint)
-            p1 = curveRect.topRight()
-            p1.setX(curveRect.topRight().x() - curveRect.width() / 2.0)
-            p2 = curveRect.bottomLeft()
-            p2.setX(curveRect.bottomLeft().x() + curveRect.width() / 2.0)
-            curvePath.moveTo(startPoint)
-            curvePath.cubicTo(p1, p2, endPoint)
-            painter.drawPath(curvePath)
-        elif style == 'sharp_bezier':
-            painter.setPen(QPen(self.__node.effectiveEdgeColor, 0.5))
-            curveRect = QRectF(startPoint, endPoint)
-            p1 = curveRect.topRight()
-            p1.setX(curveRect.topRight().x() - curveRect.width() / 2.0)
-            p2 = curveRect.bottomLeft()
-            p2.setX(curveRect.bottomLeft().x() + curveRect.width() / 2.0)
-            curvePath.moveTo(startPoint.x(), startPoint.y() + self.__node.effectiveEdgeWidth / 2.0)
-            curvePath.cubicTo(p1, p2, endPoint)
-            startPoint.setY(startPoint.y() - self.__node.effectiveEdgeWidth / 2.0)
-            curvePath.cubicTo(p2, p1, startPoint)
-            painter.drawPath(curvePath)
-            painter.fillPath(curvePath, self.__node.effectiveEdgeColor)
-        elif style == 'linear':
-            if self.__node.left:
-                startPoint, endPoint = endPoint, startPoint
-            points = QPolygonF()
-            points.append(startPoint)
-            points.append(QPointF(startPoint.x() + self.__node.effectiveEdgeWidth / 2.0, startPoint.y()))
-            points.append(QPointF(endPoint.x() - self.__node.effectiveEdgeWidth / 2.0, endPoint.y()))
-            points.append(endPoint)
-            painter.drawPolyline(points)
-        elif style == 'sharp_linear':
-            painter.setPen(QPen(self.__node.effectiveEdgeColor, 0.1))
-            curvePath.moveTo(startPoint.x(), startPoint.y() + self.__node.effectiveEdgeWidth / 2.0)
-            curvePath.lineTo(endPoint)
-            curvePath.lineTo(startPoint.x(), startPoint.y() - self.__node.effectiveEdgeWidth / 2.0)
-            painter.drawPath(curvePath)
-            painter.fillPath(curvePath, self.__node.effectiveEdgeColor)
+        curveRect = QRectF(startPoint, endPoint)
+        p1 = curveRect.topRight()
+        p1.setX(curveRect.topRight().x() - curveRect.width() / 2.0)
+        p2 = curveRect.bottomLeft()
+        p2.setX(curveRect.bottomLeft().x() + curveRect.width() / 2.0)
+        curvePath.moveTo(startPoint)
+        curvePath.cubicTo(p1, p2, endPoint)
+        painter.drawPath(curvePath)
+
+    def _paintSharpBezierEdge(self, painter, startPoint, endPoint):
+        '''
+        Paint edge with sharp bezier style
+        '''
+        curvePath = QPainterPath()
+        painter.setPen(QPen(self.__node.effectiveEdgeColor, 0.5))
+        curveRect = QRectF(startPoint, endPoint)
+        p1 = curveRect.topRight()
+        p1.setX(curveRect.topRight().x() - curveRect.width() / 2.0)
+        p2 = curveRect.bottomLeft()
+        p2.setX(curveRect.bottomLeft().x() + curveRect.width() / 2.0)
+        curvePath.moveTo(startPoint.x(), startPoint.y() + \
+                self.__node.effectiveEdgeWidth / 2.0)
+        curvePath.cubicTo(p1, p2, endPoint)
+        startPoint.setY(startPoint.y() - self.__node.effectiveEdgeWidth / 2.0)
+        curvePath.cubicTo(p2, p1, startPoint)
+        painter.drawPath(curvePath)
+        painter.fillPath(curvePath, self.__node.effectiveEdgeColor)
+
+    def _paintLinearEdge(self, painter, startPoint, endPoint):
+        '''
+        Paint edge with linear style
+        '''
+        if self.__node.left:
+            startPoint, endPoint = endPoint, startPoint
+        points = QPolygonF()
+        points.append(startPoint)
+        points.append(QPointF(startPoint.x() + self.__node.effectiveEdgeWidth / 2.0,
+                startPoint.y()))
+        points.append(QPointF(endPoint.x() - self.__node.effectiveEdgeWidth / 2.0,
+                endPoint.y()))
+        points.append(endPoint)
+        painter.drawPolyline(points)
+
+    def _paintSharpLinearEdge(self, painter, startPoint, endPoint):
+        '''
+        Paint edge with sharp linear style
+        '''
+        curvePath = QPainterPath()
+        painter.setPen(QPen(self.__node.effectiveEdgeColor, 0.1))
+        curvePath.moveTo(startPoint.x(), startPoint.y() + \
+                self.__node.effectiveEdgeWidth / 2.0)
+        curvePath.lineTo(endPoint)
+        curvePath.lineTo(startPoint.x(), startPoint.y() - \
+                self.__node.effectiveEdgeWidth / 2.0)
+        painter.drawPath(curvePath)
+        painter.fillPath(curvePath, self.__node.effectiveEdgeColor)
 
     def linkPointOffset(self):
         '''
