@@ -36,11 +36,10 @@ from hivemind.gui_delegates import *
 from hivemind.gui_widgets import *
 from hivemind.commands import *
 from PySide.QtGui import *
-from PySide import QtGui
 from PySide.QtCore import *
 from twisted.python import log
 import hivemind.gui_factory as gui_factory
-from action_bag import ActionBag
+from hivemind.action_bag import ActionBag
 
 
 # Install qt4reactor as main twisted framework reactor
@@ -99,16 +98,16 @@ class MainWindowController(QObject):
         self.__actionBag.foldNodeAction.setText(
                self.tr('Unfold node') if currentNode.folded else self.tr('Fold node'))
         self.__actionBag.foldNodeAction.setChecked(currentNode.folded is not None)
-        self.__actionBag.removeNodeAction.setEnabled(currentNode.parent is not None and\
-                self.__mode == self.MODE_NORMAL)
-        self.__actionBag.editLabelAction.setEnabled(currentNode.parent is not None and\
-                self.__mode == self.MODE_NORMAL)
-        self.__actionBag.enterTransferModeAction.setEnabled(currentNode.parent is not None and\
-                self.__mode == self.MODE_NORMAL)
-        self.__actionBag.addSiblingNodeBelowAction.setEnabled(currentNode.parent is not None and\
-                self.__mode == self.MODE_NORMAL)
-        self.__actionBag.addSiblingNodeAboveAction.setEnabled(currentNode.parent is not None and\
-                self.__mode == self.MODE_NORMAL)
+        self.__actionBag.removeNodeAction.setEnabled(
+                currentNode.parent is not None and self.__mode == self.MODE_NORMAL)
+        self.__actionBag.editLabelAction.setEnabled(
+                currentNode.parent is not None and self.__mode == self.MODE_NORMAL)
+        self.__actionBag.enterTransferModeAction.setEnabled(
+                currentNode.parent is not None and self.__mode == self.MODE_NORMAL)
+        self.__actionBag.addSiblingNodeBelowAction.setEnabled(
+                currentNode.parent is not None and self.__mode == self.MODE_NORMAL)
+        self.__actionBag.addSiblingNodeAboveAction.setEnabled(
+                currentNode.parent is not None and self.__mode == self.MODE_NORMAL)
         self.__actionBag.editEdgeAction.setEnabled(self.__mode == self.MODE_NORMAL)
         self.__actionBag.addNodeAction.setEnabled(self.__mode == self.MODE_NORMAL)
         self.__actionBag.editNodeIconsAction.setEnabled(self.__mode == self.MODE_NORMAL)
@@ -128,7 +127,8 @@ class MainWindowController(QObject):
         @type checkable: bool
         '''
         def handler():
-            self.createStateModificationCommand(self.__mindMapScene.currentNode, alteredAttributes)
+            self.createStateModificationCommand(
+                    self.__mindMapScene.currentNode, alteredAttributes)
         action.connect(SIGNAL('triggered()'), handler)
         action.setCheckable(checkable)
 
@@ -325,7 +325,8 @@ class MainWindowController(QObject):
         self.__inactiveEffect = QGraphicsBlurEffect()
         self.__inactiveEffect.setBlurRadius(3)
         self.__movingNode = self.__mindMapScene.currentNode
-        self.__mindMapScene.getDelegate(self.__movingNode).setGraphicsEffect(self.__inactiveEffect)
+        self.__mindMapScene.getDelegate(self.__movingNode) \
+                .setGraphicsEffect(self.__inactiveEffect)
         self._setActionsState(self.__mindMapScene.currentNode)
 
     def _cancelNodeMoving(self):
@@ -339,9 +340,17 @@ class MainWindowController(QObject):
         if self.__mindMapScene.currentNode.folded:
             self.foldNode()
         else:
-            location = NodeLocation()
-            self._finishNodeMoving(self.__mindMapScene.getDelegate(self.__mindMapScene.currentNode),
-                    location)
+            if self.__mindMapScene.currentNode.parent is None:
+                dialog = gui_factory.createSideSelectionDialog()
+                dialog.exec_()
+                if dialog.leftSide is None:
+                    self._cancelNodeMoving()
+                    return
+                location = NodeLocation(not dialog.leftSide)
+            else:
+                location = NodeLocation()
+            self._finishNodeMoving(self.__mindMapScene.getDelegate(
+                    self.__mindMapScene.currentNode), location)
 
     def _putNodeBelow(self):
         '''Move relocable node as sibling below relative to current node'''
@@ -406,7 +415,10 @@ class MainWindowController(QObject):
         unmodifiedAttributes = {}
         alteredAttributes = {}
         unmodifiedAttributes['folded'] = self.__mindMapScene.currentNode.folded
-        alteredAttributes['folded'] = True if self.__mindMapScene.currentNode.folded is None else None
+        if self.__mindMapScene.currentNode.folded is None:
+            alteredAttributes['folded'] = True
+        else:
+            alteredAttributes['folded'] = None
         self._recordCommand(StateModificationCommand(self.__mindMapScene.currentNode,
                 unmodifiedAttributes, alteredAttributes))
 
@@ -597,7 +609,7 @@ class MindMapController(QObject):
         '''
         fileName = QFileDialog.getSaveFileName(gui_factory.defaultParent(),
                 self.tr('Save as'), self._fileDirectory(),
-                self.tr('Mind maps (*.mm);;All Files (*)'))[0];
+                self.tr('Mind maps (*.mm);;All Files (*)'))[0]
         if not fileName: return False
         if not re.match('.*\.mm', fileName): fileName += '.mm'
         try:
@@ -759,7 +771,7 @@ class MindMapController(QObject):
 
 def _printHelp():
     '''Print general information about the application'''
-    print '''HiveMind - Distributed mind map editor for Maemo 5 platform
+    print '''HiveMind - Cross-platform collaborative mind map editor
 Copyright (C) 2010-2011 HiveMind developers
 
 Usage: hivemind [filename]
