@@ -906,7 +906,7 @@ class SpinBoxBinder(QSpinBox, ComponentBinder):
     QSpinBox binder
     @author: Oleg Kandaurov
     '''
-    def __init__(self, paramName, value, min, max, parent = None):
+    def __init__(self, paramName, value, min, max, parent = None): #pylint: disable=R0913
         '''
         Initialize binder
         @param paramName: Parameter that is binded to component
@@ -1135,8 +1135,8 @@ class FullScreenExitButton(QToolButton):
         self.setPalette(pal)
         self.setAutoFillBackground(True)
         self.setVisible(False)
-        self.connect(self, SIGNAL('clicked()'), parent, SLOT('showNormal()'));
-        parent.installEventFilter(self);
+        self.connect(self, SIGNAL('clicked()'), parent, SLOT('showNormal()'))
+        parent.installEventFilter(self)
 
     def eventFilter(self, obj, event):
         '''
@@ -1188,23 +1188,23 @@ class AffiliationDelegate(QStyledItemDelegate):
             editor.addItem(name, data)
         return editor
 
-    def setEditorData (self, editor, index):
+    def setEditorData(self, editor, index):
         '''
         Sets the data to be displayed and edited by the editor
         from the data model item specified by the model index.
         '''
         value = index.model().data(index, Qt.EditRole)
-        editor.setCurrentIndex(editor.findData(self.__supportedAffiliations[value]))
+        if value: editor.setCurrentIndex(editor.findData(value))
 
-    def setModelData (self, editor, model, index):
+    def setModelData(self, editor, model, index):
         '''
         Gets data from the editor widget and stores
         it in the specified model at the item index.
         '''
         value = editor.itemData(editor.currentIndex())
-        model.setData(index, value, Qt.EditRole)
+        if value: model.setData(index, value, Qt.EditRole)
 
-    def updateEditorGeometry (self, editor, option, index):
+    def updateEditorGeometry(self, editor, option, index):
         '''
         Updates the editor for the item specified
         by index according to the style option given.
