@@ -41,7 +41,7 @@ class MaemoDialogMixin:
     def __init__(self):
         '''Initialize mixin'''
         self.setWindowFlags(Qt.Window)
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        self.setAttribute(Qt.WA_Maemo5StackedWindow) #pylint: disable = E1103
 
     def exec_(self):
         '''This method is overriden to call show() as it is necessary on Maemo'''
@@ -68,23 +68,8 @@ class MaemoEditNodeDialog(MaemoDialogMixin, EditNodeDialog):
 
     def _initComponents(self):
         '''Form initialization'''
-        toolbar = QToolBar(self)
-        self._boldAction.setIcon(QIcon(resource.getImage('node_editor_bold')))
-        toolbar.addAction(self._boldAction)
-        self._italicAction.setIcon(QIcon(resource.getImage('node_editor_italic')))
-        toolbar.addAction(self._italicAction)
-        self._underlineAction.setIcon(QIcon(resource.getImage('node_editor_underline')))
-        toolbar.addAction(self._underlineAction)
-        self._textFontAction.setIcon(QIcon(resource.getImage('node_editor_font')))
-        toolbar.addAction(self._textFontAction)
-        self._textHtmlAction.setIcon(QIcon(resource.getImage('node_editor_html')))
-        toolbar.addAction(self._textHtmlAction)
-        self._colorAction.setIcon(QIcon(resource.getImage('node_editor_font_color')))
-        toolbar.addAction(self._colorAction)
-        self._backgroundAction.setIcon(QIcon(resource.getImage('node_editor_background_color')))
-        toolbar.addAction(self._backgroundAction)
-        self._clearFormatAction.setIcon(QIcon(resource.getImage('node_editor_clear')))
-        toolbar.addAction(self._clearFormatAction)
+        #pylint: disable = W0201
+        toolbar = self._createToolbar()
         #create edit widget
         scalingWidget = ScalingWidget(self._editor, 2.0)
         self._editor.setFrameShape(QFrame.Box)
@@ -118,11 +103,27 @@ class MaemoEditNodeDialog(MaemoDialogMixin, EditNodeDialog):
         self._textHtmlAction.connect(SIGNAL('toggled(bool)'),
                                      adaptCallable(self._showTextSourceButtons))
 
-    def _firstToolbar(self):
-        self.__stackedWidgetForToolbars.setCurrentIndex(self.__toolbarIndex)
-
-    def _secondToolbar(self):
-        self.__stackedWidgetForToolbars.setCurrentIndex(self.__fontbarIndex)
+    def _createToolbar(self):
+        '''Create editor toolbar'''
+        toolbar = QToolBar(self)
+        self._boldAction.setIcon(QIcon(resource.getImage('node_editor_bold')))
+        toolbar.addAction(self._boldAction)
+        self._italicAction.setIcon(QIcon(resource.getImage('node_editor_italic')))
+        toolbar.addAction(self._italicAction)
+        self._underlineAction.setIcon(QIcon(resource.getImage('node_editor_underline')))
+        toolbar.addAction(self._underlineAction)
+        self._textFontAction.setIcon(QIcon(resource.getImage('node_editor_font')))
+        toolbar.addAction(self._textFontAction)
+        self._textHtmlAction.setIcon(QIcon(resource.getImage('node_editor_html')))
+        toolbar.addAction(self._textHtmlAction)
+        self._colorAction.setIcon(QIcon(resource.getImage('node_editor_font_color')))
+        toolbar.addAction(self._colorAction)
+        self._backgroundAction.setIcon(QIcon(
+                        resource.getImage('node_editor_background_color')))
+        toolbar.addAction(self._backgroundAction)
+        self._clearFormatAction.setIcon(QIcon(resource.getImage('node_editor_clear')))
+        toolbar.addAction(self._clearFormatAction)
+        return toolbar
 
     def _changedMode(self, isSourceMode):
         '''
@@ -226,7 +227,7 @@ class MaemoIconDialog(MaemoDialogMixin, IconDialog):
         self.setLayout(layout)
 
 
-class MaemoAboutDialog(MaemoDialogMixin, AboutDialog):
+class MaemoAboutDialog(AboutDialog):
     '''
     About dialog for Maemo platform
 
@@ -239,6 +240,7 @@ class MaemoAboutDialog(MaemoDialogMixin, AboutDialog):
 
     def _createComponents(self):
         '''Create components'''
+        #pylint: disable = W0201
         AboutDialog._createComponents(self)
         self._logo.setPixmap(self._logoImage)
         self._visitWebsite = QPushButton(self.tr("Visit website"))
@@ -271,8 +273,8 @@ class MaemoAboutDialog(MaemoDialogMixin, AboutDialog):
         self._scrollBar.setRepeatAction(QAbstractSlider.SliderSingleStepAdd, 0, 70)
         self._scrollBar.connect(SIGNAL('actionTriggered(int)'),
                                  adaptCallable(self._scroll))
-        self._visitWebsite.connect(SIGNAL('clicked()'), self._openWebsite)
-        self._reportBug.connect(SIGNAL('clicked()'), self._openBugReport)
+        self._visitWebsite.connect(SIGNAL('clicked()'), openWebsite)
+        self._reportBug.connect(SIGNAL('clicked()'), openBugReport)
 
     def _initComponents(self):
         '''Form initialization'''
@@ -287,14 +289,6 @@ class MaemoAboutDialog(MaemoDialogMixin, AboutDialog):
         mainLayout.addLayout(buttonsLayout, 16, 14, 4, 6)
         self.setLayout(mainLayout)
 
-    def _openWebsite(self):
-        QDesktopServices.openUrl(QUrl(
-                'https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind'))
-
-    def _openBugReport(self):
-        QDesktopServices.openUrl(QUrl(
-                'https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind/issues/new'))
-
     def _scroll(self, action):
         '''
         Handle action from vertical scroll bar
@@ -409,13 +403,13 @@ class MaemoSettingsDialog(MaemoDialogMixin, SettingsDialog):
         self._newSettings.append(self._autosave.retrieve())
         SettingsDialog._accept(self)
 
-class MaemoXMPPCredentialsDialog(MaemoDialogMixin, XMPPCredentialsDialog):
+class MaemoNetworkConnectionDialog(MaemoDialogMixin, NetworkConnectionDialog):
     '''
-    XMPP credentials dialog for Maemo platform
+    Network connection dialog for Maemo platform
     @author: Oleg Kandaurov
     '''
-    def __init__(self, client = False, parent = None):
-        XMPPCredentialsDialog.__init__(self, client, parent)
+    def __init__(self, credentials, client, parent = None):
+        NetworkConnectionDialog.__init__(self, credentials, client, parent)
         MaemoDialogMixin.__init__(self)
 
 
@@ -457,7 +451,8 @@ class MaemoExtendedMenuDialog(QDialog):
         font.setPixelSize(28)
         singleClickLabel = QLabel(self.tr('Single-click on the node to show the main menu:'))
         singleClickLabel.setFont(font)
-        doubleClickLabel = QLabel(self.tr('Double-click on the node to show the additional menu:'))
+        doubleClickLabel = QLabel(
+                self.tr('Double-click on the node to show the additional menu:'))
         doubleClickLabel.setFont(font)
         layout.addWidget(singleClickLabel, 0, 0, 1, 4, Qt.AlignCenter)
         layout.addWidget(doubleClickLabel, 3, 0, 1, 4, Qt.AlignCenter)
@@ -510,3 +505,14 @@ class MaemoExtendedMenuDialog(QDialog):
         button = ActionImageButton(action)
         button.connect(SIGNAL('clicked()'), self.accept)
         return button
+
+
+def openWebsite():
+    '''Open project web page'''
+    QDesktopServices.openUrl(QUrl(
+            'https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind'))
+
+def openBugReport():
+    '''Open bug report page'''
+    QDesktopServices.openUrl(QUrl(
+            'https://linuxlab.corp7.uniyar.ac.ru/projects/hivemind/issues/new'))
