@@ -205,10 +205,10 @@ class MaemoNodeMenu(QObject):
         @return: the point on ellipse, identified by angle
         @rtype: float tuple 
         '''
-        a = self.__radiusOne
-        b = self.__radiusTwo
-        x = self.__basePoint.x() + a * math.cos(angle + MaemoNodeMenu.__INITIAL_ANGLE)
-        y = self.__basePoint.y() + b * math.sin(angle + MaemoNodeMenu.__INITIAL_ANGLE)
+        x = self.__basePoint.x() + self.__radiusOne * \
+                math.cos(angle + MaemoNodeMenu.__INITIAL_ANGLE)
+        y = self.__basePoint.y() + self.__radiusTwo * \
+                math.sin(angle + MaemoNodeMenu.__INITIAL_ANGLE)
         return x, y
 
     def _positionMenu(self):
@@ -275,8 +275,8 @@ class MaemoNodeMenu(QObject):
                     showAnimation.setStartValue(button.geometry())
                 else:
                     showAnimation.setStartValue(centerRect)
-                    showAnimation.setKeyValueAt(0.65, self._calculateTransitionalPosition(centerRect,
-                                                                                endRect, 0.4))
+                    showAnimation.setKeyValueAt(0.65,
+                            self._calculateTransitionalPosition(centerRect, endRect, 0.4))
                 showAnimation.setEndValue(endRect)
                 hideAnimation = self.__hideAnimationTransformation[button]
                 hideAnimation.setStartValue(endRect)
@@ -328,7 +328,8 @@ class MaemoNodeMenu(QObject):
                 hideAnimation = QSequentialAnimationGroup()
 
                 hideTransformationAnimation = QPropertyAnimation(button, 'geometry')
-                hideTransformationAnimation.setDuration(settings.get('hideNodeMenuAnimationDuration'))
+                hideTransformationAnimation.setDuration(
+                        settings.get('hideNodeMenuAnimationDuration'))
                 hideTransformationAnimation.setEasingCurve(QEasingCurve.OutExpo)
                 hideTransformationAnimation.setStartValue(button.geometry())
                 hideTransformationAnimation.setEndValue(centrRect)
@@ -344,7 +345,8 @@ class MaemoNodeMenu(QObject):
                 showAnimation = QSequentialAnimationGroup()
 
                 showTransformationAnimation = QPropertyAnimation(button, 'geometry')
-                showTransformationAnimation.setDuration(settings.get('showNodeMenuAnimationDuration'))
+                showTransformationAnimation.setDuration(
+                        settings.get('showNodeMenuAnimationDuration'))
                 showTransformationAnimation.setEasingCurve(QEasingCurve.InSine)
                 self.__showAnimationTransformation[button] = showTransformationAnimation
 
@@ -357,7 +359,8 @@ class MaemoNodeMenu(QObject):
                 hideAnimation = QSequentialAnimationGroup()
 
                 hideTransformationAnimation = QPropertyAnimation(button, 'geometry')
-                hideTransformationAnimation.setDuration(settings.get('hideNodeMenuAnimationDuration'))
+                hideTransformationAnimation.setDuration(
+                        settings.get('hideNodeMenuAnimationDuration'))
                 hideTransformationAnimation.setEasingCurve(QEasingCurve.OutExpo)
                 self.__hideAnimationTransformation[button] = hideTransformationAnimation
 
