@@ -27,11 +27,14 @@ Provides functions for creating a mind map object from XML file and vice versa
 @authors: Andrew Golovchenko
 '''
 
-import parser
+# Import itself to invoke its methods via getattr()
+import parser #pylint: disable=W0406
+
 from lxml import etree as xml
 from hivemind.core import *
 from hivemind.commands import *
 
+
 def _parseNode(root, parent = None):
     '''
     Save XML subtree information into a mind map node object
@@ -111,17 +114,17 @@ def _parseNode(root, parent = None):
         node.setAttributes(**storeAttrs)
     return node
 
-__INTEGERS = Set(('created', 'modified', 'hgap', 'vgap', 'vshift',
+__INTEGERS = set(('created', 'modified', 'hgap', 'vgap', 'vshift',
               'font_size', 'name_width', 'value_width'))
 '''Integer attributes'''
 
-__WIDTHS = Set(('width', 'edgeWidth'))
+__WIDTHS = set(('width', 'edgeWidth'))
 '''Width holding attributes'''
 
-__COLORS = Set(('color', 'background_color', 'edgeColor', 'labelColor'))
+__COLORS = set(('color', 'background_color', 'edgeColor', 'labelColor'))
 '''QColor attributes'''
 
-__FONTS = Set(('font', 'labelFont'))
+__FONTS = set(('font', 'labelFont'))
 '''QFont attributes'''
 
 def _castAttributes(attributes, toLowerCase = True):
@@ -275,9 +278,9 @@ def _nodeToXml(root):
         xmlElement.append(_nodeToXml(child))
     return xmlElement
 
-def _parseRoot(root):
+def _parseMindMap(root):
     '''
-    Save XML tree information into mind map object
+    Load information from XML tree into MindMap object
     
     @param root: XML tree root
     @type root: lxml Element
@@ -287,16 +290,16 @@ def _parseRoot(root):
     @return: mind map object
     @rtype: MindMap
     '''
-    mindMap = MindMap()
+    rootNode = attributeRegistry = None
     for element in root:
         if element.tag == 'attribute_registry':
-            mindMap.attributeRegistry = _parseAttrRegistry(element)
+            attributeRegistry = _parseAttrRegistry(element)
         elif element.tag == 'node':
-            mindMap.root = _parseNode(element)
+            rootNode = _parseNode(element)
             break
-    if mindMap.root is None:
+    if rootNode is None:
         raise Exception('Mind map must have root node')
-    return mindMap
+    return MindMap(rootNode, attributeRegistry)
 
 def _parseAttrRegistry(xmlElement):
     '''
@@ -399,7 +402,7 @@ def loadMindMap(filename):
     reader = QTextStream(mapFile)
     stringData = unicode(reader.readAll())
     mapFile.close()
-    return _parseRoot(xml.fromstring(stringData))
+    return _parseMindMap(xml.fromstring(stringData))
 
 def mindMapToString(mindMap, formatted = False):
     '''
@@ -414,15 +417,16 @@ def mindMapToString(mindMap, formatted = False):
     @return: mind map as XML-string
     @rtype: string
     '''
-    map = xml.Element('map', version = '0.9.0')
-    comment = xml.Comment(' To view this file, download free mind mapping software FreeMind from http://freemind.sourceforge.net ')
-    map.append(comment)
+    resultXml = xml.Element('map', version = '0.9.0')
+    comment = xml.Comment(' To view this file, download free mind mapping software ' + \
+            'FreeMind from http://freemind.sourceforge.net ')
+    resultXml.append(comment)
     if mindMap.attributeRegistry is not None:
-        map.append(_attrRegistryToXml(mindMap.attributeRegistry))
-    map.append(_nodeToXml(mindMap.root))
+        resultXml.append(_attrRegistryToXml(mindMap.attributeRegistry))
+    resultXml.append(_nodeToXml(mindMap.root))
 #    FIXME: use UTF8 encoding in new file format
 #    return xml.tostring(map, pretty_print = formatted, encoding = 'utf8')
-    return xml.tostring(map, pretty_print = formatted)
+    return xml.tostring(resultXml, pretty_print = formatted)
 
 def mindMapFromString(serializedMindMap):
     '''
@@ -434,7 +438,7 @@ def mindMapFromString(serializedMindMap):
     @return: deserialized mind map
     @rtype: MindMap
     '''
-    return _parseRoot(xml.fromstring(serializedMindMap))
+    return _parseMindMap(xml.fromstring(serializedMindMap))
 
 def _fillAddNodeCommandElement(command, commandElement):
     '''
