@@ -19,6 +19,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02111-1301  USA
+#pylint: disable=W0603
 
 '''
 Application settings manager
@@ -93,7 +94,7 @@ def get(parameter):
     else:
         return value
 
-def set(**parameters):
+def set(**parameters): #pylint: disable=W0622
     '''
     Set parameters
     '''
@@ -140,6 +141,7 @@ __signalizer = QObject()
 if 'UNITTEST' in os.environ:
     _reinitialize('/') # in order to prevert reading/writing
     def reinitialize(path = '/'):
+        '''Reinitialize __settings object for unit testing case'''
         _reinitialize(path)
 else:
     _reinitialize('%s/.config' % os.path.expanduser('~'))
